package homework.interfaces.brackets;

/**
 * Interface for the Brackets Singleton Factory.
 *
 * @author Laurentiu Stamate
 */
public interface IBracketsFactory {
  /**
   * Instantiates a bracket.
   *
   * @param bracket The bracket
   * @return An instance that inherits IBracket
   */
  IBracket createBracket(String bracket);

  /**
   * Checks whether or not a token is a bracket.
   *
   * @param token The token
   * @return The bracket status
   */
  boolean isBracket(String token);

  /**
   * Checks whether or not a token is an opened bracket.
   *
   * @param token The token
   * @return The bracket status
   */
  boolean isOpenedBracket(String token);

  /**
   * Checks whether or not a token is a closed bracket.
   *
   * @param token The token
   * @return The bracket status
   */
  boolean isClosedBracket(String token);

  /**
   * Checks whether or not two tokens are a bracket pair.
   *
   * @param openBracket  The opened bracket as a token
   * @param closeBracket The closed bracket as a token
   * @return The bracket pair status
   */
  boolean isBracketPair(String openBracket, String closeBracket);
}
